"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var CheckSyntaxPlugin_exports = {};
__export(CheckSyntaxPlugin_exports, {
  CheckSyntaxPlugin: () => CheckSyntaxPlugin
});
module.exports = __toCommonJS(CheckSyntaxPlugin_exports);
var import_path = require("path");
var import_acorn = require("acorn");
var import_fs_extra = require("@rsbuild/shared/fs-extra");
var import_helpers = require("./helpers");
var import_shared = require("@rsbuild/shared");
class CheckSyntaxPlugin {
  constructor(options) {
    this.errors = [];
    this.targets = options.targets;
    this.exclude = options.exclude;
    this.rootPath = options.rootPath;
    this.ecmaVersion = options.ecmaVersion || (0, import_helpers.getEcmaVersion)(this.targets);
  }
  apply(complier) {
    complier.hooks.afterEmit.tapPromise(
      CheckSyntaxPlugin.name,
      async (compilation) => {
        const outputPath = compilation.outputOptions.path || "dist";
        const emittedAssets = compilation.getAssets().filter((a) => a.source).map((a) => a.name).map((p) => (0, import_path.resolve)(outputPath, p));
        const files = emittedAssets.filter(
          (assets) => import_shared.HTML_REGEX.test(assets) || import_shared.JS_REGEX.test(assets)
        );
        await Promise.all(
          files.map(async (file) => {
            await this.check(file);
          })
        );
        (0, import_helpers.printErrors)(this.errors);
      }
    );
  }
  async check(filepath) {
    if (import_shared.HTML_REGEX.test(filepath)) {
      const htmlScripts = await (0, import_helpers.generateHtmlScripts)(filepath);
      await Promise.all(
        htmlScripts.map(async (script) => {
          if (!(0, import_helpers.checkIsExcludeSource)(filepath, this.exclude)) {
            await this.tryParse(filepath, script);
          }
        })
      );
    }
    if (import_shared.JS_REGEX.test(filepath)) {
      const jsScript = await import_fs_extra.fs.readFile(filepath, "utf-8");
      await this.tryParse(filepath, jsScript);
    }
  }
  async tryParse(filepath, code) {
    try {
      (0, import_acorn.parse)(code, { ecmaVersion: this.ecmaVersion });
    } catch (_) {
      const err = _;
      const error = await (0, import_helpers.generateError)({
        err,
        code,
        filepath,
        exclude: this.exclude,
        rootPath: this.rootPath
      });
      if (error) {
        this.errors.push(error);
      }
    }
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  CheckSyntaxPlugin
});
