"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var generateError_exports = {};
__export(generateError_exports, {
  displayCodePointer: () => displayCodePointer,
  generateError: () => generateError,
  makeCodeFrame: () => makeCodeFrame
});
module.exports = __toCommonJS(generateError_exports);
var import_fs_extra = require("@rsbuild/shared/fs-extra");
var import_chalk = require("@rsbuild/shared/chalk");
var import_source_map = require("source-map");
var import_utils = require("./utils");
var import_types = require("../types");
function displayCodePointer(code, pos) {
  const SUB_LEN = 80;
  const start = Math.max(pos - SUB_LEN / 2, 0);
  const subCode = code.slice(start, start + SUB_LEN);
  const arrowPos = pos - start;
  const arrowLine = import_chalk.chalk.yellow("^".padStart(arrowPos + 11, " "));
  return `${subCode}
${arrowLine}`;
}
async function generateError({
  err,
  code,
  filepath,
  rootPath,
  exclude
}) {
  let error = await tryGenerateErrorFromSourceMap({
    err,
    filepath,
    rootPath
  });
  if (!error) {
    const path = filepath.replace(rootPath, "");
    error = new import_types.SyntaxError(err.message, {
      source: {
        path,
        line: err.loc.line,
        column: err.loc.column,
        code: displayCodePointer(code, err.pos)
      }
    });
  }
  if ((0, import_utils.checkIsExcludeSource)(error.source.path, exclude)) {
    return null;
  }
  return error;
}
function makeCodeFrame(lines, highlightIndex) {
  const startLine = Math.max(highlightIndex - 3, 0);
  const endLine = Math.min(highlightIndex + 4, lines.length - 1);
  const ret = [];
  for (let i = startLine; i < endLine; i++) {
    if (i === highlightIndex) {
      const lineNumber = `> ${i + 1}`.padStart(6, " ");
      ret.push(import_chalk.chalk.yellow(`${lineNumber} | ${lines[i]}`));
    } else {
      const lineNumber = ` ${i + 1}`.padStart(6, " ");
      ret.push(import_chalk.chalk.gray(`${lineNumber} | ${lines[i]}`));
    }
  }
  return `
${ret.join("\n")}`;
}
async function tryGenerateErrorFromSourceMap({
  err,
  filepath,
  rootPath
}) {
  var _a, _b, _c, _d, _e;
  const sourceMapPath = `${filepath}.map`;
  if (!import_fs_extra.fs.existsSync(sourceMapPath)) {
    return null;
  }
  try {
    const sourcemap = await import_fs_extra.fs.readFile(sourceMapPath, "utf-8");
    const consumer = await new import_source_map.SourceMapConsumer(sourcemap);
    const sm = consumer.originalPositionFor({
      line: err.loc.line,
      column: err.loc.column
    });
    if (!sm.source) {
      return null;
    }
    const { sources } = consumer;
    const smIndex = sources.indexOf(sm.source);
    const smContent = (_b = (_a = JSON.parse(sourcemap)) == null ? void 0 : _a.sourcesContent) == null ? void 0 : _b[smIndex];
    if (!smContent) {
      return null;
    }
    const path = sm.source.replace(/webpack:\/\/(tmp)?/g, "");
    const relativeFilepath = filepath.replace(rootPath, "");
    const rawLines = smContent.split(/\r?\n/g);
    const highlightLine = ((_c = sm.line) != null ? _c : 1) - 1;
    return new import_types.SyntaxError(err.message, {
      source: {
        path,
        line: (_d = sm.line) != null ? _d : 0,
        column: (_e = sm.column) != null ? _e : 0,
        code: makeCodeFrame(rawLines, highlightLine)
      },
      output: {
        path: relativeFilepath,
        line: err.loc.line,
        column: err.loc.column
      }
    });
  } catch (e) {
    return null;
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  displayCodePointer,
  generateError,
  makeCodeFrame
});
