"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var printErrors_exports = {};
__export(printErrors_exports, {
  printErrors: () => printErrors
});
module.exports = __toCommonJS(printErrors_exports);
var import_chalk = require("@rsbuild/shared/chalk");
var import_shared = require("@rsbuild/shared");
function printErrors(errors) {
  if (errors.length === 0) {
    import_shared.logger.success("The syntax check success.");
    return;
  }
  const errs = errors.map((error) => ({
    source: `${error.source.path}:${error.source.line}:${error.source.column}`,
    output: error.output ? `${error.output.path}:${error.output.line}:${error.output.column}` : void 0,
    reason: error.message,
    code: error.source.code
  }));
  const longest = Math.max(...Object.keys(errs[0]).map((err) => err.length));
  import_shared.logger.error(
    "[Syntax Checker] Find some syntax errors after production build:\n"
  );
  errs.forEach((err, index) => {
    console.info(import_chalk.chalk.red.bold(`  ERROR ${index + 1}`));
    printMain(err, longest);
  });
  throw new Error(
    `[Syntax Checker] The current build fails due to an incompatible syntax, which can be fixed in the following ways:

  - If you want to downgrade the syntax, you can compile the corresponding module through the \`source.include\` config.
  - If you don't want to downgrade the syntax, you can adjust the project's browserslist to match the syntax.`
  );
}
function printMain(error, logest) {
  const fillWhiteSpace = (s, logest2) => {
    if (s.length < logest2) {
      const rightPadding = " ".repeat(logest2 - s.length);
      return s + rightPadding;
    }
    return s;
  };
  Object.entries(error).forEach(([key, content]) => {
    if (!content) {
      return;
    }
    const title = import_chalk.chalk.magenta(`${fillWhiteSpace(`${key}:`, logest + 1)}`);
    console.info(`  ${title}  ${content}`);
  });
  console.info("");
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  printErrors
});
